@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,19 +20,27 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
 CRUD View
 """
 
+from __future__ import unicode_literals
+
+try:
+    from sqlalchemy.inspection import inspect
+except ImportError:
+    inspect = None
+    from sqlalchemy.orm import class_mapper
+
+from pyramid.httpexceptions import HTTPFound, HTTPNotFound
+
 from .core import View
-from pyramid.httpexceptions import HTTPFound
 
 from ..forms import AlchemyForm
 from formalchemy import FieldSet
 from ..db import Session
 
-from edbob.util import requires_impl, prettify
+from edbob.util import prettify
 
 
 __all__ = ['CrudView']
@@ -46,18 +53,16 @@ class CrudView(View):
     update_cancel_route = None
 
     @property
-    @requires_impl(is_property=True)
     def mapped_class(self):
-        pass
+        raise NotImplementedError
 
     @property
     def pretty_name(self):
         return self.mapped_class.__name__
 
     @property
-    @requires_impl(is_property=True)
     def home_route(self):
-        pass
+        raise NotImplementedError
 
     @property
     def home_url(self):
@@ -175,33 +180,35 @@ class CrudView(View):
     def create(self):
         return self.crud(self.mapped_class)
 
+    def get_model_from_request(self):
+        if inspect:
+            mapper = inspect(self.mapped_class)
+        else:
+            mapper = class_mapper(self.mapped_class)
+        assert len(mapper.primary_key) == 1
+        key = self.request.matchdict[mapper.primary_key[0].key]
+        return self.get_model(key)
+
     def get_model(self, key):
         model = Session.query(self.mapped_class).get(key)
         return model
 
     def read(self):
-        key = self.request.matchdict['uuid']
-        model = self.get_model(key)
+        model = self.get_model_from_request()
         if not model:
-            return HTTPFound(location=self.home_url)
+            return HTTPNotFound()
         return self.crud(model, readonly=True)
 
     def update(self):
-        uuid = self.request.matchdict['uuid']
-        model = Session.query(self.mapped_class).get(uuid) if uuid else None
-        assert model
+        model = self.get_model_from_request()
+        if not model:
+            return HTTPNotFound()
         return self.crud(model)
 
-    def pre_delete(self, model):
-        pass
-
-    def post_delete(self, model):
-        pass
-
     def delete(self):
-        uuid = self.request.matchdict['uuid']
-        model = Session.query(self.mapped_class).get(uuid) if uuid else None
-        assert model
+        model = self.get_model_from_request()
+        if not model:
+            return HTTPNotFound()
         result = self.pre_delete(model)
         if result:
             return result
@@ -210,3 +217,9 @@ class CrudView(View):
         self.post_delete(model)
         self.flash_delete(model)
         return HTTPFound(location=self.home_url)
+
+    def pre_delete(self, model):
+        pass
+
+    def post_delete(self, model):
+        pass
