@@ -31,7 +31,7 @@ from ..progress import get_progress_session
 
 def progress(request):
     key = request.matchdict['key']
-    session = get_progress_session(request.session, key)
+    session = get_progress_session(request, key)
     if session.get('complete'):
         request.session.flash(session.get('success_msg', "The process has completed successfully."))
     elif session.get('error'):
@@ -41,7 +41,7 @@ def progress(request):
 
 def cancel(request):
     key = request.matchdict['key']
-    session = get_progress_session(request.session, key)
+    session = get_progress_session(request, key)
     session.clear()
     session['canceled'] = True
     session.save()
