@@ -35,12 +35,11 @@ from pyramid.response import Response
 
 from ..db import Session
 
-from edbob.time import local_time
-
 import rattail
 from rattail import enum
 from rattail.db import model
 from rattail.files import resource_path
+from rattail.time import localtime
 
 
 plu_upc_pattern = re.compile(r'^000000000(\d{5})$')
@@ -112,7 +111,7 @@ class OrderingWorksheet(View):
             key = '{0} {1}'.format(brand, product.description)
             return key
 
-        now = local_time()
+        now = localtime(self.request.rattail_config)
         data = dict(
             vendor=vendor,
             costs=costs,
@@ -174,7 +173,7 @@ class InventoryWorksheet(View):
             q = q.order_by(model.Brand.name, model.Product.description)
             return q.all()
 
-        now = local_time()
+        now = localtime(self.request.rattail_config)
         data = dict(
             date=now.strftime('%a %d %b %Y'),
             time=now.strftime('%I:%M %p'),
